<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr_FR">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About %1</source>
        <translation>À propos %1</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Seafile Drive Client %2&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Client Seafile Drive %2&lt;/h4&gt;</translation>
    </message>
    <message>
        <source>&lt;h5&gt; REV %1 &lt;/h5&gt;</source>
        <translation>&lt;h5&gt; RÉVISION %1 &lt;/h5&gt;</translation>
    </message>
    <message>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <source>failed to open account database</source>
        <translation>L&apos;ouverture de la base de données du compte a échoué.</translation>
    </message>
</context>
<context>
    <name>AutoLogonDialog</name>
    <message>
        <source>auto login</source>
        <translation>Connexion automatique</translation>
    </message>
    <message>
        <source>auto logining, please wait a moment</source>
        <translation>Connexion automatique, veuillez patienter.</translation>
    </message>
    <message>
        <source>Please input server address</source>
        <translation>Veuillez introduire l&apos;adresse du serveur.</translation>
    </message>
    <message>
        <source>address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Entrez l&apos;adresse du serveur</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 n&apos;est pas une adresse de serveur valide</translation>
    </message>
    <message>
        <source>login failed</source>
        <translation>Échec de la connexion</translation>
    </message>
</context>
<context>
    <name>DaemonManager</name>
    <message>
        <source>%1 failed to initialize</source>
        <translation>%1 n&apos;a pu être initialisé</translation>
    </message>
    <message>
        <source>%1 exited unexpectedly</source>
        <translation>%1 s&apos;est fermé de manière inattendue</translation>
    </message>
    <message>
        <source>Failed to initialize: failed to create seadrive mount folder</source>
        <translation>Échec de l&apos;initialisation: Le dossier de montage SeaDrive n&apos;a pas pu créé.</translation>
    </message>
</context>
<context>
    <name>EncryptedReposDialog</name>
    <message>
        <source>Encrypted Libraries</source>
        <translation>Bibliothèques chiffrées</translation>
    </message>
    <message>
        <source>No Encrypted Library.</source>
        <translation>Bibliothèque non chiffrée</translation>
    </message>
</context>
<context>
    <name>EncryptedReposTableModel</name>
    <message>
        <source>Failed to set encrypted library password</source>
        <translation>Le mot de passe de la bibliothèque chiffrée n&apos;a pas pu être défini.</translation>
    </message>
    <message>
        <source>Password error</source>
        <translation>Erreur de mot de passe</translation>
    </message>
    <message>
        <source>Failed to clear encrypted library password</source>
        <translation>Le mot de passe de la bibliothèque chiffrée n&apos;a pas pu être effacé.</translation>
    </message>
    <message>
        <source>Right click this item to sync or unsync the encrypted library</source>
        <translation>Click droit sur cet objet pour synchroniser ou de-synchroniser la bibliothèque chiffrée</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Bibliothèque</translation>
    </message>
    <message>
        <source>Sync status</source>
        <translation>Status de la synchronisation</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Serveur</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
</context>
<context>
    <name>EncryptedReposTableView</name>
    <message>
        <source>Unsync</source>
        <translation>De-synchroniser</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Synchronisé</translation>
    </message>
    <message>
        <source>After unsyncing, the local encryption key of this library will be cleared and this library cannot be accessed in virtual drive. Are you sure to unsync?</source>
        <translation>Après la de-synchronisation, la clé locale de chiffrement de la bibliothèque seras effacée, cette bibliothèque ne pourra plus être accessible dans le disque virtuel. Êtes-vous sur de vouloir de-synchroniser ?</translation>
    </message>
    <message>
        <source>Enter library password to sync</source>
        <translation>Saisir le mot de passe de la bibliothèque pour synchroniser</translation>
    </message>
</context>
<context>
    <name>ExtCommandsHandler</name>
    <message>
        <source>Are you sure to remove account from &quot;%1&quot;? Downloaded and uploading files will not be removed.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to connect to background process, please try again later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to resync account from &quot;%1&quot;? Downloaded and uploading files will not be removed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileProviderManager</name>
    <message>
        <source>%1 will ask permissions to enable Finder plugin.</source>
        <translation>%1 demandera des autorisations pour activer le plugin Finder.</translation>
    </message>
</context>
<context>
    <name>FilterMenu</name>
    <message>
        <source>FilterMenu</source>
        <translation>Menu filtre</translation>
    </message>
    <message>
        <source>Text file    </source>
        <translation>Fichier texte</translation>
    </message>
    <message>
        <source>Document    </source>
        <translation>Document</translation>
    </message>
    <message>
        <source>Image    </source>
        <translation>Image</translation>
    </message>
    <message>
        <source>Video    </source>
        <translation>Vidéo</translation>
    </message>
    <message>
        <source>Audio    </source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Markdown</source>
        <translation>Réduction</translation>
    </message>
</context>
<context>
    <name>InitSyncDialog</name>
    <message>
        <source>Download files list</source>
        <translation>Téléchargement de la liste des fichiers</translation>
    </message>
    <message>
        <source>%1 is fetching the files list, please wait</source>
        <translation>%1 récupère la liste des fichiers, veuillez patienter</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>Run in Background</source>
        <translation>Exécuter en arrière-plan</translation>
    </message>
    <message>
        <source>Finish</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <source>%1 has downloaded your files list.</source>
        <translation>%1 a téléchargé la liste de vos fichiers</translation>
    </message>
</context>
<context>
    <name>LoadMoreButton</name>
    <message>
        <source>load more</source>
        <translation>Charger plus</translation>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <source>Add an account</source>
        <translation>Ajouter un compte</translation>
    </message>
    <message>
        <source>Single Sign On</source>
        <translation>Authentification unique</translation>
    </message>
    <message>
        <source>Re-login</source>
        <translation>Reconnexion</translation>
    </message>
    <message>
        <source>Logging in...</source>
        <translation>Connexion...</translation>
    </message>
    <message>
        <source>Network Error:
 %1</source>
        <translation>Erreur réseau : %1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt;Attention :&lt;/b&gt; Le certificat de sécurité de ce serveur n&apos;est pas approuvé, continuer malgré tout ?</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Veuillez entrer l&apos;adresse du serveur</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 n&apos;est pas une adresse de serveur valide</translation>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation>Veuillez entrer le nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Please enter the computer name</source>
        <translation>Veuillez entrer le nom de l&apos;ordinateur</translation>
    </message>
    <message>
        <source>Two Factor Authentication</source>
        <translation>Authentification à deux facteurs</translation>
    </message>
    <message>
        <source>%1 Server Address</source>
        <translation>%1  adresse serveur</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Veuillez entrer le mot de passe</translation>
    </message>
    <message>
        <source>Enter the two factor authentication token</source>
        <translation>Introduisez les deux éléments de facteur d&apos;authentification</translation>
    </message>
    <message>
        <source>Incorrect email or password</source>
        <translation>E-mail ou mot de passe incorrect</translation>
    </message>
    <message>
        <source>Logging in too frequently, please wait a minute</source>
        <translation>Connexions trop fréquentes, veuillez attendre une minute</translation>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Erreur interne du serveur</translation>
    </message>
    <message>
        <source>Failed to login: %1</source>
        <translation>Impossible de se connecter ：%1</translation>
    </message>
    <message>
        <source>Failed to login</source>
        <translation>Impossible de se connecter</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>Server:</source>
        <translation>Serveur :</translation>
    </message>
    <message>
        <source>or http://192.168.1.24:8000</source>
        <translation>ou http://192.168.1.24:8000</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Mot de passe :</translation>
    </message>
    <message>
        <source>Automatic Login</source>
        <translation>Connexion automatique</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>Texte d&apos;état</translation>
    </message>
    <message>
        <source>Computer Name:</source>
        <translation>Nom de l&apos;ordinateur :</translation>
    </message>
    <message>
        <source>Email / Username:</source>
        <translation>E-mail / Nom d&apos;utilisateur :</translation>
    </message>
    <message>
        <source>e.g. Jim&apos;s laptop</source>
        <translation>Par exemple : portable de Julien</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Connexion</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Failed to get server info. Please check the server address.</source>
        <translation>Impossible d&apos;obtenir les informations du serveur. Veuillez vérifier l&apos;adresse du serveur.</translation>
    </message>
    <message>
        <source>Failed to get client sso link.</source>
        <translation>Impossible d&apos;obtenir le lien SSO du client</translation>
    </message>
    <message>
        <source>SSO login failed.</source>
        <translation>La connexion SSO a échoué.</translation>
    </message>
    <message>
        <source>Failed to get client sso status.</source>
        <translation>Impossible d&apos;obtenir l&apos;état SSO du client</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For example: https://example.your-server.com&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Par example: https://example.votre-serveur.com&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Advanced Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync Root Folder Name:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync root folder name cannot be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync root folder name cannot contain the following characters: &lt; &gt; : &quot; / \ | ? *</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Files in this account will be synced under the path like &apos;C:\Users\Jim\seadrive_root\&amp;lt;sync root folder name&amp;gt;&apos;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MessagePoller</name>
    <message>
        <source>&quot;%1&quot; is synchronized</source>
        <translation>&quot;%1&quot; est synchronisé</translation>
    </message>
    <message>
        <source>Error when syncing &quot;%1&quot;</source>
        <translation>Erreur lors de la synchronisation &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Error when syncing</source>
        <translation>Erreur lors de la synchronisation</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is being uploaded</source>
        <translation>&quot;%1&quot; est entrain d&apos;être téléversé</translation>
    </message>
    <message>
        <source>Starting to move &quot;%1&quot;</source>
        <translation>Début du déplacement de &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Starting to move &quot;%1&quot; to &quot;%2&quot;</source>
        <translation>Début du déplacement de &quot;%1&quot; vers &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Successfully moved &quot;%1&quot;</source>
        <translation>Déplacement de &quot;%1&quot; réussi</translation>
    </message>
    <message>
        <source>Successfully moved &quot;%1&quot; to &quot;%2&quot;</source>
        <translation>Déplacement de &quot;%1&quot; vers &quot;%2&quot; réussi</translation>
    </message>
    <message>
        <source>Failed to move &quot;%1&quot;</source>
        <translation>Déplacement de &quot;%1&quot; a échoué</translation>
    </message>
    <message>
        <source>Failed to move &quot;%1&quot; to &quot;%2&quot;</source>
        <translation>Déplacement de &quot;%1&quot; vers &quot;%2&quot; a échoué</translation>
    </message>
    <message>
        <source>Download file</source>
        <translation>Téléchargement de fichier</translation>
    </message>
    <message>
        <source>Start to download file &quot;%1&quot; </source>
        <translation>Début du déplacement du fichier &quot;%1&quot;</translation>
    </message>
    <message>
        <source>file &quot;%1&quot; has been downloaded </source>
        <translation>Le fichier &quot;%1&quot; à été téléchargé</translation>
    </message>
    <message>
        <source>Failed to create file &quot;%1&quot;</source>
        <translation>Échec de la création du fichier &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed to delete folder</source>
        <translation>Échec de la suppression du dossier</translation>
    </message>
    <message>
        <source>You can&apos;t delete the library &quot;%1&quot; directly</source>
        <translation>Vous ne pouvez supprimer la bibliothèque &quot;%1&quot; directement</translation>
    </message>
    <message>
        <source>Libraries are ready</source>
        <translation>Les bibliothèques sont prêtes</translation>
    </message>
    <message>
        <source>All libraries are loaded and ready to use.</source>
        <translation>Toutes les bibliothèques sont chargées et prêtes à être utilisées.</translation>
    </message>
    <message>
        <source>Deleted &quot;%1&quot; and %2 more files.</source>
        <translation>Suppression du fichier &quot;%1&quot; et de %2 autres fichiers.</translation>
    </message>
    <message>
        <source>You can&apos;t create files in the mount folder directly</source>
        <translation>Vous ne pouvez pas créer directement des fichiers dans le dossier de montage</translation>
    </message>
    <message>
        <source>Do you want to delete files in library &quot;%1&quot; ?</source>
        <translation>Voulez-vous supprimer les fichiers de la bibliothèque &quot;%1&quot; ?</translation>
    </message>
    <message>
        <source>Deleted library &quot;%1&quot;</source>
        <translation>Bibliothèque &quot;%1&quot; supprimée</translation>
    </message>
    <message>
        <source>Confirm to delete library &quot;%1&quot; ?</source>
        <translation>Confirmer la suppression de la bibliothèque &quot;%1&quot; ?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>File %1 is locked by other programs</source>
        <translation>Le fichier %1 est utilisé par d&apos;autres programmes</translation>
    </message>
    <message>
        <source>Some file is locked by other programs</source>
        <translation>Certains fichiers sont utilisés par d&apos;autres programmes</translation>
    </message>
    <message>
        <source>Folder %1 is locked by other programs</source>
        <translation>Le dossier %1 est utilisé par d&apos;autres programmes</translation>
    </message>
    <message>
        <source>Some folder is locked by other programs</source>
        <translation>Certains dossiers sont utilisés par d&apos;autres programmes</translation>
    </message>
    <message>
        <source>File %1 is locked by another user</source>
        <translation>Le fichier %1 est utilisé par un autre utilisateur</translation>
    </message>
    <message>
        <source>Some file is locked by another user</source>
        <translation>Certains fichiers sont utilisés par un autre utilisateur</translation>
    </message>
    <message>
        <source>Invalid path %1</source>
        <translation>Le chemin de %1 est incorrect</translation>
    </message>
    <message>
        <source>Trying to access an invalid path</source>
        <translation>Tentative d&apos;accéder à un chemin incorrect</translation>
    </message>
    <message>
        <source>Error when indexing file %1</source>
        <translation>Erreur lors de l’indexation du fichier %1</translation>
    </message>
    <message>
        <source>Error when indexing files</source>
        <translation>Erreur lors de l&apos;indexation des fichiers</translation>
    </message>
    <message>
        <source>You don&apos;t have enough permission for this library</source>
        <translation>Vous n&apos;avez le niveau de permissions suffisant pour accéder à cette bibliothèque</translation>
    </message>
    <message>
        <source>Network error</source>
        <translation>Erreur réseau</translation>
    </message>
    <message>
        <source>Failed to resolve network proxy</source>
        <translation>Echec de la résolution du proxy réseau</translation>
    </message>
    <message>
        <source>Failed to resolve remote server</source>
        <translation>Échec de la résolution du serveur distant</translation>
    </message>
    <message>
        <source>Failed to connect to server</source>
        <translation>Échec de la connexion au serveur</translation>
    </message>
    <message>
        <source>SSL error</source>
        <translation>Erreur SSL</translation>
    </message>
    <message>
        <source>Error in network transmission</source>
        <translation>Erreur dans la transmission réseau</translation>
    </message>
    <message>
        <source>Timeout in network transmission</source>
        <translation>Timeout dans la transmission réseau</translation>
    </message>
    <message>
        <source>Failed to handle http redirection</source>
        <translation>Échec de la redirection http</translation>
    </message>
    <message>
        <source>Server internal error</source>
        <translation>Erreur interne du serveur</translation>
    </message>
    <message>
        <source>Local data is corrupt</source>
        <translation>Les données locales sont corrompues</translation>
    </message>
    <message>
        <source>Failed to write local data</source>
        <translation>Échec de l&apos;écriture des données locales</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Erreur inconnue</translation>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation>Le quota de stockage est atteint</translation>
    </message>
    <message>
        <source>SSL Error</source>
        <translation>Erreur SSL</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Erreur réseau : %1</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation>Erreur du serveur</translation>
    </message>
    <message>
        <source>Created library &quot;%1&quot;</source>
        <translation>Bibliothèque &quot;%1&quot; créée</translation>
    </message>
    <message>
        <source>Deleted library &quot;%1&quot;</source>
        <translation>Bibliothèque &quot;%1&quot; supprimée</translation>
    </message>
    <message>
        <source>Added</source>
        <translation>Ajouté</translation>
    </message>
    <message>
        <source>Deleted</source>
        <translation>Supprimé</translation>
    </message>
    <message>
        <source>Removed</source>
        <translation>Déplacé</translation>
    </message>
    <message>
        <source>Modified</source>
        <translation>Modifié</translation>
    </message>
    <message>
        <source>Renamed</source>
        <translation>Renommé</translation>
    </message>
    <message>
        <source>Added or modified</source>
        <translation>Ajouté ou modifié</translation>
    </message>
    <message>
        <source>Moved</source>
        <translation>Déplacé</translation>
    </message>
    <message>
        <source>Added directory</source>
        <translation>Répertoire ajouté</translation>
    </message>
    <message>
        <source>Removed directory</source>
        <translation>Répertoire supprimé</translation>
    </message>
    <message>
        <source>Renamed directory</source>
        <translation>Répertoire renommé</translation>
    </message>
    <message>
        <source>Moved directory</source>
        <translation>Répertoire déplacé</translation>
    </message>
    <message>
        <source>files</source>
        <translation>Fichiers</translation>
    </message>
    <message>
        <source>directories</source>
        <translation>Répertoires</translation>
    </message>
    <message>
        <source>and %1 more</source>
        <translation>ainsi que %1</translation>
    </message>
    <message>
        <source>Reverted library to status at</source>
        <translation>Retour de la bibliothèque à l&apos;état du</translation>
    </message>
    <message>
        <source>Reverted file &quot;%1&quot; to status at %2.</source>
        <translation>Retour du fichier &quot;%1&quot; à l&apos;état du %2</translation>
    </message>
    <message>
        <source>Recovered deleted directory</source>
        <translation>Restauration de la bibliothèque effacée</translation>
    </message>
    <message>
        <source>Changed library name or description</source>
        <translation>Changement du nom ou de la description de la bibliothèque</translation>
    </message>
    <message>
        <source>Auto merge by %1 system</source>
        <translation>Fusion automatique par %1 système</translation>
    </message>
    <message>
        <source>Just now</source>
        <translation>À l&apos;instant</translation>
    </message>
    <message>
        <source>1 day ago</source>
        <translation>Il y a un jour</translation>
    </message>
    <message>
        <source>%1 days ago</source>
        <translation>Il y a %1 jours</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>Il y a 1 heure</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>Il y a %1 heures</translation>
    </message>
    <message>
        <source>1 minute ago</source>
        <translation>Il y a 1 minute</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>Il y a %1 minutes</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Dossier</translation>
    </message>
    <message>
        <source>Readonly Folder</source>
        <translation>Dossier en lecture seule</translation>
    </message>
    <message>
        <source>Document</source>
        <translation>Document</translation>
    </message>
    <message>
        <source>PDF Document</source>
        <translation>Document PDF</translation>
    </message>
    <message>
        <source>Image File</source>
        <translation>Fichier image</translation>
    </message>
    <message>
        <source>Text Document</source>
        <translation>Document texte</translation>
    </message>
    <message>
        <source>Audio File</source>
        <translation>Fichier audio</translation>
    </message>
    <message>
        <source>Video File</source>
        <translation>Fichier vidéo</translation>
    </message>
    <message>
        <source>Word Document</source>
        <translation>Document Word</translation>
    </message>
    <message>
        <source>PowerPoint Document</source>
        <translation>Document PowerPoint</translation>
    </message>
    <message>
        <source>Excel Document</source>
        <translation>Document Excel</translation>
    </message>
    <message>
        <source>%1 Client is already running</source>
        <translation>Le client %1 est déjà en cours d&apos;exécution</translation>
    </message>
    <message>
        <source>Choose the disk letter for %1</source>
        <translation>Choisissez une lettre pour le disque %1</translation>
    </message>
    <message>
        <source>Update to file %1 denied by folder permission setting</source>
        <translation>La mise à jour du fichier %1 est impossible dû aux paramètres de permission du dossier.</translation>
    </message>
    <message>
        <source>Path %1 ends with space or period character</source>
        <translation>Le chemin %1 se termine par un espace ou un point</translation>
    </message>
    <message>
        <source>Path %1 contains invalid characters like &apos;|&apos; or &apos;:&apos;</source>
        <translation>Le chemin %1 contient des caractères invalides comme &quot;|&quot; ou &apos;:&apos;</translation>
    </message>
    <message>
        <source>Created or updated a file %1 in a non-writable library or folder</source>
        <translation>Création ou mise à jour du fichier %1 dans une bibliothèque ou un dossier non inscriptible</translation>
    </message>
    <message>
        <source>Concurrent updates to file %1. File is saved as conflict file</source>
        <translation>Mises à jour simultanées du fichier %1. Le fichier est enregistré comme fichier de conflit</translation>
    </message>
    <message>
        <source>%1 is not added to a library and will not be uploaded</source>
        <translation>Le fichier %1 ne peut pas êtres ajouté à la bibliothèque, il ne seras pas téléversé.</translation>
    </message>
    <message>
        <source>You can only move files/folders within a library or from one library to another library</source>
        <translation>Vous ne pouvez déplacer des fichiers/dossiers qu&apos;au sein d&apos;une bibliothèque ou d&apos;une bibliothèque à une autre.</translation>
    </message>
    <message>
        <source>Syncing is denied by cloud-only permission settings</source>
        <translation>La synchronisation est refusée par les paramètres d&apos;autorisation en nuage-uniquement.</translation>
    </message>
    <message>
        <source>Do not have write permission to the library</source>
        <translation>Vous n&apos;avez pas le droit d&apos;écriture dans la bibliothèque</translation>
    </message>
    <message>
        <source>Waiting for confirmation to delete files</source>
        <translation>Attente de la confirmation de suppression des fichiers</translation>
    </message>
    <message>
        <source>The path %1 contains symbols that are not supported by the Windows system.</source>
        <translation>Le chemin du fichier %1 contient des symboles qui ne sont pas supportés par le système Windows.</translation>
    </message>
    <message>
        <source>Failed to upload file blocks. Please check network or firewall.</source>
        <translation>Échec du téléchargement des blocs de fichiers. Veuillez vérifier le réseau ou le pare-feu.</translation>
    </message>
    <message>
        <source>Failed to download file. Please check disk space or folder permissions</source>
        <translation>Le téléchargement du fichier a échoué. Veuillez vérifier l&apos;espace sur le disque dur ou  les autorisations du dossier.</translation>
    </message>
    <message>
        <source>Library cannot be synced since it has too many files.</source>
        <translation>La bibliothèque ne peut pas être synchronisée. Elle contient trop de fichiers.</translation>
    </message>
    <message>
        <source>Files cannot be uploaded to this library due to file number limit settings.</source>
        <translation>Les fichiers ne peuvent pas être importés vers cette bibliothèque. La limite du nombre de fichiers est dépassé.</translation>
    </message>
    <message>
        <source>Path has character case conflict with existing file or folder. Will not be downloaded</source>
        <translation>Le chemin d&apos;accès présente un conflit de caractères avec un fichier ou un dossier existant. Le téléchargement n&apos;est pas éffectué.</translation>
    </message>
    <message>
        <source>Failed to change library name since some files are opened in it</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RemoteWipeService</name>
    <message>
        <source>Authorization expired, please re-login</source>
        <translation>L&apos;autorisation a expiré, veuillez vous reconnecter</translation>
    </message>
    <message>
        <source>Authorization expired, please re-login. You can find files that are not uploaded yet at ~/Library/CloudStorage</source>
        <translation>L&apos;autorisation a expirée. Veuillez vous reconnecter. Vous pouvez trouver les fichiers qui n&apos;ont pas encore été envoyés dans ~/Library/CloudStorage</translation>
    </message>
</context>
<context>
    <name>SeaDriveRootDialog</name>
    <message>
        <source>Choose SeaDrive Cache Folder</source>
        <translation>Choisissez le dossier de cache SeaDrive</translation>
    </message>
    <message>
        <source>Your files will appear in a local cache folder. Please choose the folder:</source>
        <translation>Vos fichiers apparaîtront dans un dossier cache local. Veuillez choisir le dossier : </translation>
    </message>
    <message>
        <source>choose...</source>
        <translation>Choisir...</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Choose %1 Cache Folder </source>
        <translation>Choisissez le dossier de cache %1</translation>
    </message>
    <message>
        <source>Choose %1 Cache Folder</source>
        <translation>Choisissez le dossier de cache %1</translation>
    </message>
    <message>
        <source>Please choose %1 cache folder</source>
        <translation>Veuillez choisir le dossier de cache %1</translation>
    </message>
    <message>
        <source>Create %1 folder failed!</source>
        <translation>La création du dossier %1 a échoué.</translation>
    </message>
</context>
<context>
    <name>SeadriveGui</name>
    <message>
        <source>Failed to initialize log: %1</source>
        <translation>Impossible d&apos;initialiser log : %1</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>failed to save client id</source>
        <translation>Impossible de sauvegarder l&apos;ID du client</translation>
    </message>
    <message>
        <source>failed to access %1</source>
        <translation>Impossible d&apos;accéder à %1</translation>
    </message>
    <message>
        <source>incorrect client id</source>
        <translation>L&apos;ID du client est incorrecte</translation>
    </message>
    <message>
        <source>failed to read %1</source>
        <translation>Impossible de lire %1</translation>
    </message>
    <message>
        <source>Auto logon failed, fall back to manual login</source>
        <translation>La connexion automatique a échoué, revenez à la connexion manuelle.</translation>
    </message>
    <message>
        <source>Faild to choose a cache directory</source>
        <translation>Impossible de choisir le répertoire de cache.</translation>
    </message>
    <message>
        <source>Failed to initialize: failed to create %1 folder</source>
        <translation>Échec de l&apos;initialisation : échec de la création du dossier %1</translation>
    </message>
    <message>
        <source>Failed to initialize: failed to create %1 logs folder</source>
        <translation>Échec de l&apos;initialisation : échec de la création du dossier de journaux %1</translation>
    </message>
    <message>
        <source>Failed to initialize: failed to create %1 data folder</source>
        <translation>Échec de l&apos;initialisation : échec de la création du dossier de données %1</translation>
    </message>
    <message>
        <source>Failed to create seadrive cache directory</source>
        <translation>Impossible de créer le répertoire de cache de SeaDrive.</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>Faild to migrate old data</source>
        <translation>La migration des anciennes données a échoué.</translation>
    </message>
    <message>
        <source>SeaDrive %1 with multiple accounts cannot work with macOS version lower than 14.4. Please upgrade your macOS or downgrade SeaDrive to 3.0.9</source>
        <translation>SeaDrive %1 avec plusieurs comptes ne peut pas fonctionner avec une version de macOS inférieure à 14.4. Veuillez mettre à jour votre macOS ou rétrograder SeaDrive à la version 3.0.9.</translation>
    </message>
    <message>
        <source>To start %1 extension for account %2, you need to click the %3 entry in Finder</source>
        <translation>Afin de lancer l&apos;extension %1 pour le compte %2, veuillez cliquer sur l&apos;élément %3 dans le Finder.</translation>
    </message>
</context>
<context>
    <name>SeafileExtensionHandler</name>
    <message>
        <source>Failed to get upload link information for file &quot;%1&quot;</source>
        <translation>Impossible de récupérer les informations du lien d&apos;envoi du fichier &quot;%1&quot;</translation>
    </message>
    <message>
        <source>No permissions to create a shared link</source>
        <translation>Aucune autorisation pour créer un lien partagé</translation>
    </message>
    <message>
        <source>failed get internal link %1</source>
        <translation>Impossible d&apos;obtenir le lien interne %1</translation>
    </message>
    <message>
        <source>Failed to lock file</source>
        <translation>Impossible de verrouiller le fichier.</translation>
    </message>
    <message>
        <source>Failed to unlock file</source>
        <translation>Impossible de déverrouiller le fichier.</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; is locked by %2</source>
        <translation>Le fichier &quot;%1&quot; est verrouillé par %2</translation>
    </message>
    <message>
        <source>Failed to get lock information for file &quot;%1&quot;</source>
        <translation>Impossible de récupérer les informations de verrouillage du fichier &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed to get share link %1
</source>
        <translation>Impossible d&apos;obtenir le lien de partage %1
</translation>
    </message>
</context>
<context>
    <name>SeafileLinkDialog</name>
    <message>
        <source>%1 Internal Link</source>
        <translation>%1 lien interne</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Copier dans le presse-papiers</translation>
    </message>
    <message>
        <source>%1 Internal Link:</source>
        <translation>%1 Lien interne :</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>SeafileRpcClient</name>
    <message>
        <source>internal error: failed to connect to %1 daemon</source>
        <translation>erreur interne : échec de la connexion au démon %1</translation>
    </message>
</context>
<context>
    <name>SeafileTrayIcon</name>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>Show file sync errors</source>
        <translation>Afficher le fichier des erreurs de synchronisation</translation>
    </message>
    <message>
        <source>Open &amp;logs folder</source>
        <translation>Ouvrir le dossier &amp;logs</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;À propos</translation>
    </message>
    <message>
        <source>Show the application&apos;s About box</source>
        <translation>Voir la boite de dialogue À propos</translation>
    </message>
    <message>
        <source>&amp;Online help</source>
        <translation>Aide en &amp;Ligne</translation>
    </message>
    <message>
        <source>Accounts</source>
        <translation>Comptes</translation>
    </message>
    <message>
        <source>not logged in</source>
        <translation>Non connecté</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Add an account</source>
        <translation>Ajouter un compte</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <source>&lt;h2&gt;Seafile Drive Client %2&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;Client Seafile Drive %2&lt;/h2&gt;</translation>
    </message>
    <message>
        <source>Up %1, Down %2</source>
        <translation>Haut %1, Bas %2</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>À propos de %1</translation>
    </message>
    <message>
        <source>Transfer progress</source>
        <translation>Progression du transfert</translation>
    </message>
    <message>
        <source>open %1 log folder</source>
        <translation>Ouvrir le dossier de log %1</translation>
    </message>
    <message>
        <source>open %1 online help</source>
        <translation>Ouvrir l&apos;aide en ligne de %1</translation>
    </message>
    <message>
        <source>Show encrypted libraries</source>
        <translation>Voir les bibliothèques chiffrées</translation>
    </message>
    <message>
        <source>Starting ...</source>
        <translation>Démarrage ...</translation>
    </message>
    <message>
        <source>Resync</source>
        <translation>Resynchroniser</translation>
    </message>
    <message>
        <source>There are changes being uploaded under the account, please try again later</source>
        <translation>Des modifications sont en cours de téléchargement sur le compte, veuillez réessayer plus tard.</translation>
    </message>
    <message>
        <source>Are you sure to remove account from &quot;%1&quot;? After removing account, you can still find downloaded files at ~/Library/CloudStorage.</source>
        <translation>Êtes-vous sûr de vouloir supprimer le compte de &quot;%1&quot;? Après avoir supprimé le compte, vous pouvez toujours trouver les fichiers téléchargés dans ~/Bibliothèque/CloudStorage.</translation>
    </message>
    <message>
        <source>Failed to connect to background process, please try again later</source>
        <translation>La connexion au processus d&apos;arrière-plan a échoué. Veuillez réessayer plus tard.</translation>
    </message>
    <message>
        <source>SeaDrive %1 with multiple accounts cannot work with macOS version lower than 14.4. Please upgrade your macOS or downgrade SeaDrive to 3.0.9</source>
        <translation>SeaDrive %1 avec plusieurs comptes ne peut pas fonctionner avec une version de macOS inférieure à 14.4. Veuillez mettre à jour votre macOS ou rétrograder SeaDrive à la version 3.0.9.</translation>
    </message>
    <message>
        <source>Search files</source>
        <translation>Rechercher des fichiers</translation>
    </message>
    <message>
        <source>Are you sure to remove account from &quot;%1&quot;? Downloaded and uploading files will not be removed.</source>
        <translation>Êtes-vous sûr de vouloir supprimer le compte de &quot;%1&quot;? Les fichiers téléchargés et envoyés ne seront pas supprimés.</translation>
    </message>
    <message>
        <source>Are you sure to resync account from &quot;%1&quot;? Downloaded and uploading files will not be removed</source>
        <translation>Êtes-vous sûr de vouloir resyncroniser le compte de &quot;%1&quot;? Les fichiers téléchargés et envoyés ne seront pas supprimés.</translation>
    </message>
    <message>
        <source>Are you sure to resync account from &quot;%1&quot;? After resyncing account, you can still find downloaded files at ~/Library/CloudStorage.</source>
        <translation>Êtes-vous sûr de vouloir resyncroniser le compte de &quot;%1&quot;? Après avoir resyncronisé le compte, vous pouvez toujours trouver les fichiers téléchargés dans ~/Bibliothèque/CloudStorage.</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <source>Search files</source>
        <translation>Rechercher des fichiers</translation>
    </message>
    <message>
        <source>All file types</source>
        <translation>Tous types de fichiers</translation>
    </message>
    <message>
        <source>Custom file type</source>
        <translation>Type de fichier personnalisé</translation>
    </message>
    <message>
        <source>retry</source>
        <translation>Réessayer</translation>
    </message>
    <message>
        <source>Failed to search&lt;br/&gt;Please %1</source>
        <translation>Impossible de rechercher&lt;br/&gt;Please %1</translation>
    </message>
    <message>
        <source>No result found</source>
        <translation>Aucun résultat</translation>
    </message>
</context>
<context>
    <name>SearchItemsTableModel</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Kind</source>
        <translation>Type</translation>
    </message>
</context>
<context>
    <name>SearchItemsTableView</name>
    <message>
        <source>&amp;Open the file</source>
        <translation>&amp;Ouvrir le fichier</translation>
    </message>
    <message>
        <source>&amp;Show in folder</source>
        <translation>&amp;Afficher dans le dossier</translation>
    </message>
    <message>
        <source>File not found, maybe not synchorized yet</source>
        <translation>Fichier non trouvé, peut-être qu&apos;il n&apos;est pas encore synchronisé.</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>Auto start %1 after login</source>
        <translation>Démarrage automatique %1 après connexion</translation>
    </message>
    <message>
        <source>Cache directory:</source>
        <translation>Répertoire du cache :</translation>
    </message>
    <message>
        <source>Enable search</source>
        <translation>Activer la recherche</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>Proxy HTTP</translation>
    </message>
    <message>
        <source>Socks5 Proxy</source>
        <translation>Proxy Socks5</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy système </translation>
    </message>
    <message>
        <source>enabled search</source>
        <translation>Recherche activée</translation>
    </message>
    <message>
        <source>disabled search</source>
        <translation>Désactiver la recherche</translation>
    </message>
    <message>
        <source>You have %1. Restart to apply it?</source>
        <translation>Vous avez %1. Redémarrer pour l&apos;appliquer ?</translation>
    </message>
    <message>
        <source>Please choose the cache folder</source>
        <translation>Veuillez choisir le répertoire du cache</translation>
    </message>
    <message>
        <source>The proxy host address can&apos;t be empty</source>
        <translation>L&apos;adresse du serveur proxy ne peut être vide</translation>
    </message>
    <message>
        <source>The proxy port is incorrect</source>
        <translation>Le port proxy est erroné</translation>
    </message>
    <message>
        <source>Proxy username can&apos;t be empty</source>
        <translation>Le nom d&apos;utilisateur du proxy ne peut être vide</translation>
    </message>
    <message>
        <source>Proxy password can&apos;t be empty</source>
        <translation>Le mot de passe du proxy ne peut être vide</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <source>Notify when libraries are synchronized</source>
        <translation>Signaler lorsque les bibliothèques sont synchronisées</translation>
    </message>
    <message>
        <source>Enable sync temporary files of MSOffice/Libreoffice</source>
        <translation>Activer la synchronisation des fichiers temporaires MSOffice/LibreOffice</translation>
    </message>
    <message>
        <source>Download speed limit (KB/s):</source>
        <translation>Vitesse de téléchargement maximum (Ko/s) :</translation>
    </message>
    <message>
        <source>Upload speed limit (KB/s):</source>
        <translation>Vitesse d&apos;envoi maximum (Ko/s) :</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Basique</translation>
    </message>
    <message>
        <source>Enable Explorer Extension</source>
        <translation>Activer l&apos;extension Explorer</translation>
    </message>
    <message>
        <source>Do not verify server certificate in HTTPS syncing</source>
        <translation>Ne pas vérifier le certificat serveur lors de la synchronisation en HTTPS</translation>
    </message>
    <message>
        <source>Cache clean interval (in minutes):</source>
        <translation>Intervalle du nettoyage du cache (en minutes) :</translation>
    </message>
    <message>
        <source>Cache size limit (in GB):</source>
        <translation>Limite de la taille du cache (en Go) :</translation>
    </message>
    <message>
        <source>select...</source>
        <translation>Sélectionner...</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avancé</translation>
    </message>
    <message>
        <source>Language (need restart)</source>
        <translation>Langue (redémarrage nécessaire)</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Langue</translation>
    </message>
    <message>
        <source>Proxy Type:</source>
        <translation>Type de proxy :</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Serveur :</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port :</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Identifiant :</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Mot de passe :</translation>
    </message>
    <message>
        <source>Proxy server requires a password</source>
        <translation>Le serveur proxy requiert un mot de passe</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Réseau</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Enable search in finder</source>
        <translation>Activer la recherche dans le Finder</translation>
    </message>
    <message>
        <source>You have changed language, Restart to apply it?</source>
        <translation>Vous avez changé la langue ? Redémarrez pour appliquer.</translation>
    </message>
    <message>
        <source>You have changed cache directory. Restart to apply it?</source>
        <translation>Vous avez changé le répertoire de cache? Redémarrez pour l&apos;appliquer.</translation>
    </message>
    <message>
        <source>You have changed %1 cache folder. Restart to apply it?</source>
        <translation>Vous avez modifié le dossier de cache %1. Redémarrez pour appliquer ?</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>Hide Windows incompatibility paths Message</source>
        <translation>Masquer les messages de Windows relatifs aux incompatibilités des chemins d&apos;accès</translation>
    </message>
    <message>
        <source>Confirm before deleting files more than</source>
        <translation>Confirmez avant de supprimer des fichiers de plus de </translation>
    </message>
</context>
<context>
    <name>SharedLinkDialog</name>
    <message>
        <source>Share Link</source>
        <translation>Lien de partage</translation>
    </message>
    <message>
        <source>Share link:</source>
        <translation>Lien de partage :</translation>
    </message>
    <message>
        <source>Direct Download</source>
        <translation>Téléchargement direct</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Copier dans le presse-papiers</translation>
    </message>
    <message>
        <source>Show password</source>
        <translation>Voir le mot de passe.</translation>
    </message>
    <message>
        <source>Expire days</source>
        <translation>Délais d&apos;expiration</translation>
    </message>
    <message>
        <source>Generate link</source>
        <translation>Générer un lien de partage</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe :</translation>
    </message>
    <message>
        <source>Failed to generate share link: %1</source>
        <translation>Impossible de générer un lien de partage: %1</translation>
    </message>
</context>
<context>
    <name>ShibLoginDialog</name>
    <message>
        <source>Single Sign On</source>
        <translation>Authentification unique</translation>
    </message>
</context>
<context>
    <name>SyncCommand</name>
    <message>
        <source>No permissions to create a shared link</source>
        <translation>Aucune autorisation pour créer un lien partagé</translation>
    </message>
    <message>
        <source>failed to get share link %1</source>
        <translation>Impossible d&apos;obtenir le lien de partage %1</translation>
    </message>
    <message>
        <source>failed get internal link %1</source>
        <translation>Impossible d&apos;obtenir le lien interne %1</translation>
    </message>
    <message>
        <source>Failed to get upload link for file &quot;%1&quot;</source>
        <translation>Impossible d&apos;obtenir le lien d&apos;envoi du fichier &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>SyncErrorsDialog</name>
    <message>
        <source>File Sync Errors</source>
        <translation>Erreurs de synchronisation de fichiers</translation>
    </message>
    <message>
        <source>No sync errors.</source>
        <translation>Pas d&apos;erreur de synchronisation</translation>
    </message>
</context>
<context>
    <name>SyncErrorsTableModel</name>
    <message>
        <source>Double click to open the library</source>
        <translation>Double clic pour ouvrir la bibliothèque</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Bibliothèque</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Chemin</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Heure</translation>
    </message>
</context>
<context>
    <name>TransferItemsTableModel</name>
    <message>
        <source>finished</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Progression</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Serveur</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Identifiant</translation>
    </message>
</context>
<context>
    <name>TransferProgressDialog</name>
    <message>
        <source>Transfer Progress</source>
        <translation>Progression du transfert</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Envoi</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Téléchargement</translation>
    </message>
</context>
<context>
    <name>UninstallHelperDialog</name>
    <message>
        <source>Uninstall %1</source>
        <translation>Désinstallation %1</translation>
    </message>
    <message>
        <source>Do you want to remove the %1 account information?</source>
        <translation>Souhaitez-vous supprimer les informations du compte %1 ?</translation>
    </message>
    <message>
        <source>Removing account information...</source>
        <translation>Suppression des informations du compte...</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <source>text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Non</translation>
    </message>
</context>
<context>
    <name>UploadLinkDialog</name>
    <message>
        <source>Upload Link</source>
        <translation>Lien de téléversement</translation>
    </message>
    <message>
        <source>Upload link:</source>
        <translation>Lien de téléversement :</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Copier dans le presse-papier</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
</TS>